==> qtjambi-debuginfo-macos-5.15.18.jar: sources/QtJambiGui/GLDEBUGPROC_shell.cpp <==
#include "GLDEBUGPROC_shell.h"
#include <QtJambi/RegistryAPI>
#include <QtJambi/FunctionPointer>
#include <QtJambi/Cast>
// emitting (writeShellConstructor)
void deleter_GLDEBUGPROC(void *ptr,bool) { delete reinterpret_cast<GLDEBUGPROC_shell*>(ptr); }


GLDEBUGPROC_shell::GLDEBUGPROC_shell()
    : FunctionalBase()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("GLDEBUGPROC_shell::GLDEBUGPROC_shell()")
    GLDEBUGPROC_shell::__shell()->constructed(typeid(GLDEBUGPROC));
}

// emitting (writeShellDestructor)
GLDEBUGPROC_shell::~GLDEBUGPROC_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("GLDEBUGPROC_shell::~GLDEBUGPROC_shell()", GLDEBUGPROC_shell::__shell())
    if(m_functionPointerDeleter)
        m_functionPointerDeleter();
    GLDEBUGPROC_shell::__shell()->destructed(typeid(GLDEBUGPROC));
}

// construct GLDEBUGPROC_shell
void __qt_construct_GLDEBUGPROC_0(void* __qtjambi_ptr, JNIEnv*, jobject, jvalue*)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct GLDEBUGPROC")
    new (__qtjambi_ptr) GLDEBUGPROC_shell();
}
// destruct GLDEBUGPROC_shell
void __qt_destruct_GLDEBUGPROC(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct GLDEBUGPROC")
    reinterpret_cast<GLDEBUGPROC_shell*>(ptr)->~GLDEBUGPROC_shell();
}

void GLDEBUGPROC_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<GLDEBUGPROC_shell*>(ptr)->GLDEBUGPROC_shell::__shell()->tryDeleteShell(typeid(GLDEBUGPROC));
}

QtJambiShell* GLDEBUGPROC_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(GLDEBUGPROC_shell) ); }

GLDEBUGPROC_shell::Functor::Functor(GLDEBUGPROC_shell& functional) : FunctorBase(typeid(GLDEBUGPROC), functional) {}

GLDEBUGPROC_shell::Functor::Functor(const Functor& functor) : FunctorBase(functor) {}

GLDEBUGPROC_shell::Functor::~Functor() {}

void GLDEBUGPROC_shell::Functor::operator()(GLenum source0, GLenum type1, GLuint id2, GLenum severity3, GLsizei length4, const GLchar* message5, const void* userParam6)
{
    if (jmethodID method_id = javaMethod()) {
        if (JniEnvironment env{900}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if (jobject __java_this = getJavaObjectLocalRef(env)) {
                    Q_UNUSED(userParam6)
                    jstring __java_message5 = qtjambi_cast<jstring>(env, QString::fromLocal8Bit(message5, length4));
                    env->CallVoidMethod(__java_this, method_id, source0, type1, id2, severity3, __java_message5);
                    JavaException::check(env QTJAMBI_STACKTRACEINFO );
                }
            } QTJAMBI_CATCH(const JavaException& exn) {
                __qj_exnhandler.handle(env, exn, "GLDEBUGPROC");
            } QTJAMBI_TRY_END
        }
    }
}

void GLDEBUGPROC_shell::getFunctional(JNIEnv *env, void* result)
{
        jobject __this = GLDEBUGPROC_shell::__shell()->getJavaObjectLocalRef(env);
        uint hash = QtJambiAPI::getJavaObjectIdentity(env, __this);
        *reinterpret_cast<GLDEBUGPROC*>(result) = qtjambi_function_pointer<14,void(GLenum,GLenum,GLuint,GLenum,GLsizei,const GLchar*,const void*)>(Functor(*this), hash, &m_functionPointerDeleter, reverseFunctionGetter ? nullptr : &reverseFunctionGetter);
}

jobject GLDEBUGPROC_shell::resolveFunctional(JNIEnv * env, const GLDEBUGPROC* function)
{
    if(function && reverseFunctionGetter){
        if(const GLDEBUGPROC_shell::Functor* functor = reverseFunctionGetter(*function)){
            return functor->getJavaObjectLocalRef(env);
        }
    }
    return nullptr;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_gl_GLDEBUGPROC_00024Impl_00024ConcreteWrapper_accept__IIIILjava_lang_String_2)
(JNIEnv *__jni_env, jobject __this, jint source0, jint type1, jint id2, jint severity3, jstring message5)
{
    QTJAMBI_NATIVE_METHOD_CALL("GLDEBUGPROC(...)")
    QtJambiScope __qtjambi_scope(__jni_env, __this);
    Q_UNUSED(__qtjambi_scope)
    QTJAMBI_TRY {
        GLDEBUGPROC* function = QtJambiAPI::convertJavaInterfaceToNative<GLDEBUGPROC>(__jni_env, __this);
        QtJambiAPI::checkNullPointer(__jni_env, function);
        J2CStringBuffer __qt_message5(__jni_env, message5);
        GLsizei length4 = GLsizei(__qt_message5.length());
        const void * __qt_userParam6 = nullptr;
        (*function)(static_cast<GLenum>(source0), static_cast<GLenum>(type1), static_cast<GLuint>(id2), static_cast<GLenum>(severity3), static_cast<GLsizei>(length4), __qt_message5, __qt_userParam6);
    } QTJAMBI_CATCH(const JavaException& exn) {
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_gl_GLDEBUGPROC_00024Impl_initialize_1native)
(JNIEnv *__jni_env, jclass __jni_class, jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("GLDEBUGPROC_shell")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_GLDEBUGPROC_0, sizeof(GLDEBUGPROC_shell), typeid(GLDEBUGPROC), &deleter_GLDEBUGPROC);
    } QTJAMBI_CATCH(const JavaException& exn) {
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
}

std::function<const GLDEBUGPROC_shell::Functor*(GLDEBUGPROC)> GLDEBUGPROC_shell::reverseFunctionGetter = std::function<const GLDEBUGPROC_shell::Functor*(GLDEBUGPROC)>();

void initialize_meta_info_GLDEBUGPROC(){
    using namespace RegistryAPI;
    registerFunctionalTypeInfo<GLDEBUGPROC, GLDEBUGPROC_shell>("GLDEBUGPROC", "io/qt/gui/gl/GLDEBUGPROC",
                              &deleter_GLDEBUGPROC,
                              &__qt_destruct_GLDEBUGPROC,
                              {ConstructorInfo(&__qt_construct_GLDEBUGPROC_0, nullptr)},
                              {FunctionInfo("accept", "(IIIILjava/lang/String;)V", FunctionInfo::Abstract)});
}

==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiGui/GLDEBUGPROC_shell.cpp <==
#include "GLDEBUGPROC_shell.h"
#include <QtJambi/RegistryAPI>
#include <QtJambi/FunctionPointer>
#include <QtJambi/Cast>
// emitting (writeShellConstructor)
void deleter_GLDEBUGPROC(void *ptr,bool) { delete reinterpret_cast<GLDEBUGPROC_shell*>(ptr); }


GLDEBUGPROC_shell::GLDEBUGPROC_shell()
    : FunctionalBase()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("GLDEBUGPROC_shell::GLDEBUGPROC_shell()")
    GLDEBUGPROC_shell::__shell()->constructed(typeid(GLDEBUGPROC));
}

// emitting (writeShellDestructor)
GLDEBUGPROC_shell::~GLDEBUGPROC_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("GLDEBUGPROC_shell::~GLDEBUGPROC_shell()", GLDEBUGPROC_shell::__shell())
    if(m_functionPointerDeleter)
        m_functionPointerDeleter();
    GLDEBUGPROC_shell::__shell()->destructed(typeid(GLDEBUGPROC));
}

// construct GLDEBUGPROC_shell
void __qt_construct_GLDEBUGPROC(void* __qtjambi_ptr, JNIEnv*, jobject, jvalue*, bool)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct GLDEBUGPROC")
    new (__qtjambi_ptr) GLDEBUGPROC_shell();
}
// destruct GLDEBUGPROC_shell
void __qt_destruct_GLDEBUGPROC(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct GLDEBUGPROC")
    reinterpret_cast<GLDEBUGPROC_shell*>(ptr)->~GLDEBUGPROC_shell();
}

void GLDEBUGPROC_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<GLDEBUGPROC_shell*>(ptr)->GLDEBUGPROC_shell::__shell()->tryDeleteShell(typeid(GLDEBUGPROC));
}

QtJambiShell* GLDEBUGPROC_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(GLDEBUGPROC_shell) ); }

GLDEBUGPROC_shell::Functor::Functor(GLDEBUGPROC_shell& functional) : FunctorBase(typeid(GLDEBUGPROC), functional) {}

GLDEBUGPROC_shell::Functor::Functor(const Functor& functor) : FunctorBase(functor) {}

GLDEBUGPROC_shell::Functor::~Functor() {}

void GLDEBUGPROC_shell::Functor::operator()(GLenum source0, GLenum type1, GLuint id2, GLenum severity3, GLsizei length4, const GLchar* message5, const void* userParam6)
{
    if (jmethodID method_id = javaMethod()) {
        if (JniEnvironment env{900}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if (jobject __java_this = getJavaObjectLocalRef(env)) {
                    Q_UNUSED(userParam6)
                    jstring __java_message5 = qtjambi_cast<jstring>(env, QString::fromLocal8Bit(message5, length4));
                    env->CallVoidMethod(__java_this, method_id, source0, type1, id2, severity3, __java_message5);
                    JavaException::check(env QTJAMBI_STACKTRACEINFO );
                }
            } QTJAMBI_CATCH(const JavaException& exn) {
                __qj_exnhandler.handle(env, exn, "GLDEBUGPROC");
            } QTJAMBI_TRY_END
        }
    }
}

void GLDEBUGPROC_shell::getFunctional(JNIEnv *env, void* result)
{
        jobject __this = GLDEBUGPROC_shell::__shell()->getJavaObjectLocalRef(env);
        uint hash = QtJambiAPI::getJavaObjectIdentity(env, __this);
        *reinterpret_cast<GLDEBUGPROC*>(result) = qtjambi_function_pointer<14,void(GLenum,GLenum,GLuint,GLenum,GLsizei,const GLchar*,const void*)>(Functor(*this), hash, &m_functionPointerDeleter, reverseFunctionGetter ? nullptr : &reverseFunctionGetter);
}

jobject GLDEBUGPROC_shell::resolveFunctional(JNIEnv * env, const void* functionPtr, bool* ok)
{
    if(functionPtr && reverseFunctionGetter){
        const GLDEBUGPROC& function = *reinterpret_cast<const GLDEBUGPROC*>(functionPtr);
        if(const GLDEBUGPROC_shell::Functor* functor = reverseFunctionGetter(function)){
            if(ok)
                *ok = true;
            return functor->getJavaObjectLocalRef(env);
        }
        if(ok)
            *ok = !function;
    }
    return nullptr;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_gl_GLDEBUGPROC_00024Impl_00024ConcreteWrapper_accept__IIIILjava_lang_String_2)
(JNIEnv *__jni_env, jobject __this, jint source0, jint type1, jint id2, jint severity3, jstring message5)
{
    QTJAMBI_NATIVE_METHOD_CALL("GLDEBUGPROC(...)")
    QtJambiScope __qtjambi_scope(__jni_env, __this);
    Q_UNUSED(__qtjambi_scope)
    QTJAMBI_TRY {
        GLDEBUGPROC* function = QtJambiAPI::convertJavaInterfaceToNative<GLDEBUGPROC>(__jni_env, __this);
        QtJambiAPI::checkNullPointer(__jni_env, function);
        J2CStringBuffer __qt_message5(__jni_env, message5);
        GLsizei length4 = GLsizei(__qt_message5.length());
        const void * __qt_userParam6 = nullptr;
        (*function)(static_cast<GLenum>(source0), static_cast<GLenum>(type1), static_cast<GLuint>(id2), static_cast<GLenum>(severity3), static_cast<GLsizei>(length4), __qt_message5, __qt_userParam6);
    } QTJAMBI_CATCH(const JavaException& exn) {
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_gl_GLDEBUGPROC_00024Impl_initialize_1native)
(JNIEnv *__jni_env, jclass __jni_class, jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("GLDEBUGPROC_shell")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_GLDEBUGPROC, sizeof(GLDEBUGPROC_shell), typeid(GLDEBUGPROC), &deleter_GLDEBUGPROC);
    } QTJAMBI_CATCH(const JavaException& exn) {
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
}

std::function<const GLDEBUGPROC_shell::Functor*(GLDEBUGPROC)> GLDEBUGPROC_shell::reverseFunctionGetter = std::function<const GLDEBUGPROC_shell::Functor*(GLDEBUGPROC)>();

void initialize_meta_info_GLDEBUGPROC(){
    using namespace RegistryAPI;
    registerFunctionalTypeInfo<GLDEBUGPROC, GLDEBUGPROC_shell>("GLDEBUGPROC", "io/qt/gui/gl/GLDEBUGPROC",
                              &deleter_GLDEBUGPROC,
                              &__qt_destruct_GLDEBUGPROC,
                              {ConstructorInfo(&__qt_construct_GLDEBUGPROC, nullptr)},
                              {FunctionInfo("accept", "(IIIILjava/lang/String;)V", FunctionInfo::Abstract)});
}
